package dev.shadowsoffire.apotheosis.adventure.compat;

package .var.folders.cl.9twcgjfx4vsg5zl73c6wxmvm0000gn.T;

import com.google.common.base.Preconditions;
import com.mojang.datafixers.kinds.App;
import com.mojang.datafixers.kinds.Applicative;
import com.mojang.serialization.Codec;
import com.mojang.serialization.codecs.RecordCodecBuilder;
import dev.shadowsoffire.apotheosis.Apotheosis;
import dev.shadowsoffire.apotheosis.adventure.affix.Affix;
import dev.shadowsoffire.apotheosis.adventure.compat.AdventureTwilightCompat;
import dev.shadowsoffire.apotheosis.adventure.loot.LootRarity;
import dev.shadowsoffire.apotheosis.adventure.socket.gem.GemClass;
import dev.shadowsoffire.apotheosis.adventure.socket.gem.bonus.GemBonus;
import java.util.Map;
import java.util.function.BiFunction;
import net.minecraft.ChatFormatting;
import net.minecraft.network.chat.Component;
import net.minecraft.network.chat.MutableComponent;
import net.minecraft.util.StringUtil;
import net.minecraft.world.entity.Entity;
import net.minecraft.world.entity.LivingEntity;
import net.minecraft.world.item.ItemStack;
import twilightforest.capabilities.CapabilityList;
import twilightforest.capabilities.shield.IShieldCapability;

public class FortificationBonus extends GemBonus {
  public static final Codec<FortificationBonus> CODEC;
  
  protected final Map<LootRarity, Data> values;
  
  static {
    CODEC = RecordCodecBuilder.create(inst -> inst.group(gemClass(), (App)LootRarity.mapCodec(Data.CODEC).fieldOf("values").forGetter(())).apply((Applicative)inst, dev.shadowsoffire.apotheosis.adventure.compat.AdventureTwilightCompat.FortificationBonus::new));
  }
  
  public FortificationBonus(GemClass gemClass, Map<LootRarity, Data> values) {
    super(Apotheosis.loc("twilight_fortification"), gemClass);
    this.values = values;
  }
  
  public void doPostHurt(ItemStack gem, LootRarity rarity, LivingEntity user, Entity attacker) {
    Data d = this.values.get(rarity);
    if (Affix.isOnCooldown(getCooldownId(gem), d.cooldown, user))
      return; 
    if (user.f_19796_.m_188501_() <= d.chance) {
      user.getCapability(CapabilityList.SHIELDS).ifPresent(cap -> cap.replenishShields());
      Affix.startCooldown(getCooldownId(gem), user);
    } 
  }
  
  public Codec<? extends GemBonus> getCodec() {
    return (Codec)CODEC;
  }
  
  public GemBonus validate() {
    Preconditions.checkArgument(!this.values.isEmpty(), "No values provided!");
    return this;
  }
  
  public boolean supports(LootRarity rarity) {
    return this.values.containsKey(rarity);
  }
  
  public int getNumberOfUUIDs() {
    return 0;
  }
  
  public Component getSocketBonusTooltip(ItemStack gem, LootRarity rarity) {
    Data d = this.values.get(rarity);
    MutableComponent mutableComponent = Component.m_237110_("affix.apotheosis.cooldown", new Object[] { StringUtil.m_14404_(d.cooldown) });
    return (Component)Component.m_237110_("bonus." + getId() + ".desc", new Object[] { Affix.fmt(d.chance * 100.0F), mutableComponent }).m_130940_(ChatFormatting.YELLOW);
  }
}
